@@ -13,7 +13,7 @@ package Printer::ESCPOS;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -140,7 +140,7 @@ Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printe
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -275,9 +275,9 @@ Use this attribute to send commands to the printer
     $device->printer->setFont('a');
     $device->printer->write("blah blah blah\n");
 
-=head1 MANUALS
+=head1 USAGE
 
-Refer to the following manuals for to get started with L<Printer::ESCPOS>
+Refer to the following manual to get started with L<Printer::ESCPOS>
 
 =over
 
@@ -287,13 +287,35 @@ L<Printer::ESCPOS::Manual>
 
 =back
 
+=head2 Quick usage summary in steps:
+
+=over
+
+=item 1.
+
+Create a device object $device by providing parameters for one of the supported printer types. Call $device-E<gt>printer-E<gt>init to initialize the printer.
+
+=item 2.
+
+call write() and other Text formatting functions on $device-E<gt>printer for the data to be sent to the printer. Make sure to end it all with a linefeed $device-E<gt>printer-E<gt>lf().
+
+=item 3.
+
+Then call the print() method to dispatch the sequences from the module buffer to the printer
+
+=back
+
+     $device->printer->print()
+
+Note: While you may call print() after every single command code, this is not advisable as some printers tend to choke up if you send them too many print commands in quick succession. To avoid this, aggregate the data to be sent to the printer with write() and other text formatting functions and then send it all in one go using print() at the very end.
+
 =head1 NOTES
 
 =over
 
 =item *
 
-In Serial mode if the printer prints out garbled characters instead of proper text, try specifying the baudrate parameter when creating printer object when you create the printer object. The default baudrate is set at 38400
+In Serial mode if the printer prints out garbled characters instead of proper text, try specifying the baudrate parameter when you create the printer object. The default baudrate is set at 38400
 
 =back
 
@@ -311,32 +333,6 @@ For ESC-P codes refer the guide from Epson http:E<sol>E<sol>support.epson.ruE<so
 
 =back
 
-=head1 USAGE
-
-=over
-
-=item *
-
-This Module offers a object oriented interface to ESC-POS Printers.
-
-=item *
-
-Create a device object $device by providing parameters for one of the supported printer types. Call $device-E<gt>printer-E<gt>init to initialize the printer.
-
-=item *
-
-call write() and other Text formatting functions on $device-E<gt>printer for the data to be sent to the printer. Make sure to end it all with a linefeed $device-E<gt>printer-E<gt>lf().
-
-=item *
-
-Then call the print() method to dispatch the sequences from the module buffer to the printer
-
-=back
-
-     $device->printer->print()
-
-Note: While you may call print() after every single command code, this is not advisable as some printers tend to choke up if you send them too many commands print commands too quickly. To avoid this aggregate the data to be sent to the printer with write() and other text formatting functions and then send it all in one go using print()
-
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
